==> clean_android_design-0.0.46.tar.gz: lib/src/settings/clean_android_design_style.dart <==
import 'package:flutter/material.dart';

final textStyleDefault = TextStyle(
  color: Colors.grey[600],
  fontWeight: FontWeight.w400,
  fontSize: 15,
  fontFamily: 'Roboto',
  decoration: TextDecoration.none,
);

final inputBoxDecoration = BoxDecoration(
  color: Color.fromARGB(255, 235, 235, 235),
  borderRadius: BorderRadius.circular(20.0),
);

final textStyleSmallHeader = TextStyle(
  color: Colors.black,
  fontWeight: FontWeight.w600,
  fontSize: 16,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

final textStyleLight = TextStyle(
  fontWeight: FontWeight.w300,
  fontSize: textStyleDefault.fontSize,
  color: textStyleDefault.color,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

final textStyleInputHeader = TextStyle(
  fontWeight: FontWeight.w500,
  fontSize: 14,
  color: textStyleDefault.color,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

class TextStyles {
  static TextStyle textStyleSize(double size) {
    return textStyleDefault.copyWith(fontSize: size);
  }

  static TextStyle defaultTextStyle() {
    return textStyleDefault;
  }
}

class CleanAndroidDesignDefaultColors {
  static Color defaultColor;
  static Color background;
  static Color defaultColorLight;
  static Color black;
  static Color accent;
  static Color accentLight;
  static Color error;
  static Color highlight;
  static Color selected;

  CleanAndroidDesignDefaultColors(
      {Color background = const Color.fromRGBO(243, 243, 243, 1),
      Color defaultColor = const Color.fromRGBO(70, 70, 70, 1),
      Color defaultColorLight = const Color.fromRGBO(230, 230, 230, 1),
      Color black = const Color.fromRGBO(37, 37, 37, 1),
      Color accent = const Color.fromRGBO(196, 90, 16, 1),
      Color accentLight = const Color.fromRGBO(214, 102, 24, 1),
      Color error = const Color.fromRGBO(211, 47, 47, 1),
      Color highlight = Colors.green,
      Color selected = const Color.fromRGBO(196, 90, 16, 1)}) {
    CleanAndroidDesignDefaultColors.background = background;
    CleanAndroidDesignDefaultColors.defaultColor = defaultColor;
    CleanAndroidDesignDefaultColors.defaultColorLight = defaultColorLight;
    CleanAndroidDesignDefaultColors.black = black;
    CleanAndroidDesignDefaultColors.accent = accent;
    CleanAndroidDesignDefaultColors.accentLight = accentLight;
    CleanAndroidDesignDefaultColors.error = error;
    CleanAndroidDesignDefaultColors.highlight = highlight;
    CleanAndroidDesignDefaultColors.selected = selected;
  }
}

==> clean_android_design-0.1.0.tar.gz: lib/src/settings/clean_android_design_style.dart <==
import 'package:flutter/material.dart';

final textStyleDefault = TextStyle(
  color: Colors.grey[600],
  fontWeight: FontWeight.w400,
  fontSize: 15,
  fontFamily: 'Roboto',
  decoration: TextDecoration.none,
);

final inputBoxDecoration = BoxDecoration(
  color: Color.fromARGB(255, 235, 235, 235),
  borderRadius: BorderRadius.circular(20.0),
);

final textStyleSmallHeader = TextStyle(
  color: Colors.black,
  fontWeight: FontWeight.w600,
  fontSize: 16,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

final textStyleLight = TextStyle(
  fontWeight: FontWeight.w300,
  fontSize: textStyleDefault.fontSize,
  color: textStyleDefault.color,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

final textStyleInputHeader = TextStyle(
  fontWeight: FontWeight.w500,
  fontSize: 14,
  color: textStyleDefault.color,
  fontFamily: textStyleDefault.fontFamily,
  decoration: textStyleDefault.decoration,
);

class TextStyles {
  static TextStyle textStyleSize(double size) {
    return textStyleDefault.copyWith(fontSize: size);
  }

  static TextStyle defaultTextStyle() {
    return textStyleDefault;
  }
}

class CleanAndroidDesignDefaultColors {
  static Color? defaultColor;
  static Color? background;
  static Color? defaultColorLight;
  static Color? black;
  static Color? accent;
  static Color? accentLight;
  static Color? error;
  static Color? highlight;
  static late Color selected;

  CleanAndroidDesignDefaultColors(
      {Color background = const Color.fromRGBO(243, 243, 243, 1),
      Color defaultColor = const Color.fromRGBO(70, 70, 70, 1),
      Color defaultColorLight = const Color.fromRGBO(230, 230, 230, 1),
      Color black = const Color.fromRGBO(37, 37, 37, 1),
      Color accent = const Color.fromRGBO(196, 90, 16, 1),
      Color accentLight = const Color.fromRGBO(214, 102, 24, 1),
      Color error = const Color.fromRGBO(211, 47, 47, 1),
      Color highlight = Colors.green,
      Color selected = const Color.fromRGBO(196, 90, 16, 1)}) {
    CleanAndroidDesignDefaultColors.background = background;
    CleanAndroidDesignDefaultColors.defaultColor = defaultColor;
    CleanAndroidDesignDefaultColors.defaultColorLight = defaultColorLight;
    CleanAndroidDesignDefaultColors.black = black;
    CleanAndroidDesignDefaultColors.accent = accent;
    CleanAndroidDesignDefaultColors.accentLight = accentLight;
    CleanAndroidDesignDefaultColors.error = error;
    CleanAndroidDesignDefaultColors.highlight = highlight;
    CleanAndroidDesignDefaultColors.selected = selected;
  }
}
